@@ -1,8 +1,8 @@
 # Copyright © 2017 Tom Hacohen
 #
 # This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, version 3.
+# it under the terms of the GNU Lesser General Public License as
+# published by the Free Software Foundation, version 3.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,27 +20,37 @@ import os
 import hashlib
 import hmac
 
-try:
-    import scrypt
-
+if hasattr(hashlib, 'scrypt'):
     def derive_key(user_password, salt):
-        return scrypt.hash(password=user_password.encode(),
-                           salt=salt.encode(),
-                           N=16384,
-                           r=8,
-                           p=1,
-                           buflen=190)
+        return hashlib.scrypt(password=user_password.encode(),
+                              salt=salt.encode(),
+                              n=16384,
+                              r=8,
+                              p=1,
+                              dklen=190)
 
-except ImportError:
-    import pyscrypt
+else:
+    try:
+        import scrypt
 
-    def derive_key(user_password, salt):
-        return pyscrypt.hash(password=user_password.encode(),
-                             salt=salt.encode(),
-                             N=16384,
-                             r=8,
-                             p=1,
-                             dkLen=190)
+        def derive_key(user_password, salt):
+            return scrypt.hash(password=user_password.encode(),
+                               salt=salt.encode(),
+                               N=16384,
+                               r=8,
+                               p=1,
+                               buflen=190)
+
+    except ImportError:
+        import pyscrypt
+
+        def derive_key(user_password, salt):
+            return pyscrypt.hash(password=user_password.encode(),
+                                 salt=salt.encode(),
+                                 N=16384,
+                                 r=8,
+                                 p=1,
+                                 dkLen=190)
 
 from . import exceptions
 
